==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QWhatsThisClickedEvent_shell.cpp <==
#include "QWhatsThisClickedEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QWhatsThisClickedEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QWhatsThisClickedEvent")
    QWhatsThisClickedEvent *_ptr = reinterpret_cast<QWhatsThisClickedEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QWhatsThisClickedEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QWhatsThisClickedEvent_shell) ); }

jmethodID QWhatsThisClickedEvent_shell::__shell_javaMethod(int pos) const { return QWhatsThisClickedEvent_shell::__shell()->javaMethod(typeid(QWhatsThisClickedEvent), pos); }

// emitting (writeShellConstructor)
QWhatsThisClickedEvent_shell::QWhatsThisClickedEvent_shell(const QString& href0)
    : QWhatsThisClickedEvent(href0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QWhatsThisClickedEvent::QWhatsThisClickedEvent_shell(const QString& href0)", QWhatsThisClickedEvent_shell::__shell())
    QWhatsThisClickedEvent_shell::__shell()->constructed(typeid(QWhatsThisClickedEvent));
}

QWhatsThisClickedEvent_shell::QWhatsThisClickedEvent_shell(const QWhatsThisClickedEvent& arg__1)
    : QWhatsThisClickedEvent(arg__1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QWhatsThisClickedEvent::QWhatsThisClickedEvent_shell(const QWhatsThisClickedEvent& arg__1)", QWhatsThisClickedEvent_shell::__shell())
    QWhatsThisClickedEvent_shell::__shell()->constructed(typeid(QWhatsThisClickedEvent));
}

// emitting (writeShellDestructor)
QWhatsThisClickedEvent_shell::~QWhatsThisClickedEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QWhatsThisClickedEvent::~QWhatsThisClickedEvent()", QWhatsThisClickedEvent_shell::__shell())
    QWhatsThisClickedEvent_shell::__shell()->destructed(typeid(QWhatsThisClickedEvent));
}

void QWhatsThisClickedEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QWhatsThisClickedEvent_shell*>(ptr)->QWhatsThisClickedEvent_shell::__shell()->tryDeleteShell(typeid(QWhatsThisClickedEvent));
}

// emitting Virtual overrides (virtualFunctions)
QWhatsThisClickedEvent* QWhatsThisClickedEvent_shell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QWhatsThisClickedEvent::clone()const", QWhatsThisClickedEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QWhatsThisClickedEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QWhatsThisClickedEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QWhatsThisClickedEvent* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QWhatsThisClickedEvent_shell::__shell()->warnForMethod("QWhatsThisClickedEvent::clone()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QWhatsThisClickedEvent::clone()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QWhatsThisClickedEvent::clone();
        }
    }else{
        return QWhatsThisClickedEvent::clone();
    }
}

void QWhatsThisClickedEvent_shell::setAccepted(bool accepted0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QWhatsThisClickedEvent::", QWhatsThisClickedEvent_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QWhatsThisClickedEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, accepted0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QWhatsThisClickedEvent_shell::__shell()->warnForMethod("QWhatsThisClickedEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QWhatsThisClickedEvent::");
            } QTJAMBI_TRY_END
        }else{
            QEvent::setAccepted(static_cast<bool>(accepted0));
        }
    }else{
        QEvent::setAccepted(static_cast<bool>(accepted0));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
void QWhatsThisClickedEvent_access::__qt_assign_cref_QWhatsThisClickedEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0)
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    const QWhatsThisClickedEvent& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QWhatsThisClickedEvent>(__jni_env, other0);
    QWhatsThisClickedEvent::operator=(__qt_other0);
}

// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QWhatsThisClickedEvent_access::__qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QWhatsThisClickedEvent* __qt_return_value = QWhatsThisClickedEvent::clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    } else {
        QWhatsThisClickedEvent* __qt_return_value = clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QWhatsThisClickedEvent(QString)
void __qt_construct_QWhatsThisClickedEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWhatsThisClickedEvent(QString)")
    jstring href0 = static_cast<jstring>(__java_arguments[0].l);
    QString  __qt_href0 = qtjambi_cast<QString>(__jni_env, href0);
    QWhatsThisClickedEvent *__qt_this = new(__qtjambi_ptr) QWhatsThisClickedEvent_shell(__qt_href0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QWhatsThisClickedEvent(QWhatsThisClickedEvent)
void __qt_construct_QWhatsThisClickedEvent_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWhatsThisClickedEvent(QWhatsThisClickedEvent)")
    jobject arg__1 = __java_arguments[0].l;
    const QWhatsThisClickedEvent& __qt_arg__1 = qtjambi_cast<const QWhatsThisClickedEvent& >(__jni_env, arg__1);
    QWhatsThisClickedEvent *__qt_this = new(__qtjambi_ptr) QWhatsThisClickedEvent_shell(__qt_arg__1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QWhatsThisClickedEvent_shell
void __qt_destruct_QWhatsThisClickedEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QWhatsThisClickedEvent")
    reinterpret_cast<QWhatsThisClickedEvent_shell*>(ptr)->~QWhatsThisClickedEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QWhatsThisClickedEvent::QWhatsThisClickedEvent(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QWhatsThisClickedEvent_initialize_1native__Lio_qt_gui_QWhatsThisClickedEvent_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jstring href0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWhatsThisClickedEvent::QWhatsThisClickedEvent(QString)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = href0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWhatsThisClickedEvent_0, sizeof(QWhatsThisClickedEvent_shell), typeid(QWhatsThisClickedEvent), true, &deleter_QWhatsThisClickedEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWhatsThisClickedEvent::QWhatsThisClickedEvent(QWhatsThisClickedEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QWhatsThisClickedEvent_initialize_1native__Lio_qt_gui_QWhatsThisClickedEvent_2Lio_qt_gui_QWhatsThisClickedEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWhatsThisClickedEvent::QWhatsThisClickedEvent(QWhatsThisClickedEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWhatsThisClickedEvent_1, sizeof(QWhatsThisClickedEvent_shell), typeid(QWhatsThisClickedEvent), true, &deleter_QWhatsThisClickedEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWhatsThisClickedEvent::href()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QWhatsThisClickedEvent_href_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QWhatsThisClickedEvent *__qt_this = QtJambiAPI::objectFromNativeId<QWhatsThisClickedEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWhatsThisClickedEvent::href()const", __qt_this)
        QString __qt_return_value = __qt_this->href();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWhatsThisClickedEvent::operator=(QWhatsThisClickedEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QWhatsThisClickedEvent_assign_1native_1cref_1QWhatsThisClickedEvent__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWhatsThisClickedEvent *__qt_this = QtJambiAPI::objectFromNativeId<QWhatsThisClickedEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWhatsThisClickedEvent::operator=(QWhatsThisClickedEvent)", __qt_this)
        static_cast<QWhatsThisClickedEvent_access*>(__qt_this)->__qt_assign_cref_QWhatsThisClickedEvent(__jni_env, __this_nativeId, other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWhatsThisClickedEvent::clone()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QWhatsThisClickedEvent_clone_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWhatsThisClickedEvent *__qt_this = QtJambiAPI::objectFromNativeId<QWhatsThisClickedEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWhatsThisClickedEvent::clone()const", __qt_this)
        __java_return_value = static_cast<const QWhatsThisClickedEvent_access*>(__qt_this)->__qt_clone(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QWhatsThisClickedEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QWhatsThisClickedEvent>("QWhatsThisClickedEvent", "io/qt/gui/QWhatsThisClickedEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/gui/QWhatsThisClickedEvent;"),
        FunctionInfo(/* 1 */ "setAccepted", "(Z)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QWhatsThisClickedEvent, {
        ConstructorInfo(&__qt_construct_QWhatsThisClickedEvent_0, "Ljava/lang/String;")
       ,ConstructorInfo(&__qt_construct_QWhatsThisClickedEvent_1, "Lio/qt/gui/QWhatsThisClickedEvent;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QWhatsThisClickedEvent);
    registerSizeOfShell(typeId, sizeof(QWhatsThisClickedEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QWhatsThisClickedEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QWhatsThisClickedEvent_shell.cpp <==
#include "QWhatsThisClickedEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QWhatsThisClickedEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QWhatsThisClickedEvent")
    QWhatsThisClickedEvent *_ptr = reinterpret_cast<QWhatsThisClickedEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QWhatsThisClickedEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QWhatsThisClickedEvent_shell) ); }

jmethodID QWhatsThisClickedEvent_shell::__shell_javaMethod(int pos) const { return QWhatsThisClickedEvent_shell::__shell()->javaMethod(typeid(QWhatsThisClickedEvent), pos); }

// emitting (writeShellConstructor)
QWhatsThisClickedEvent_shell::QWhatsThisClickedEvent_shell(const QString& href0)
    : QWhatsThisClickedEvent(href0)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QWhatsThisClickedEvent::QWhatsThisClickedEvent_shell(const QString& href0)", QWhatsThisClickedEvent_shell::__shell())
    QWhatsThisClickedEvent_shell::__shell()->constructed(typeid(QWhatsThisClickedEvent));
}

QWhatsThisClickedEvent_shell::QWhatsThisClickedEvent_shell(const QWhatsThisClickedEvent& arg__1)
    : QWhatsThisClickedEvent(arg__1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QWhatsThisClickedEvent::QWhatsThisClickedEvent_shell(const QWhatsThisClickedEvent& arg__1)", QWhatsThisClickedEvent_shell::__shell())
    QWhatsThisClickedEvent_shell::__shell()->constructed(typeid(QWhatsThisClickedEvent));
}

// emitting (writeShellDestructor)
QWhatsThisClickedEvent_shell::~QWhatsThisClickedEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QWhatsThisClickedEvent::~QWhatsThisClickedEvent()", QWhatsThisClickedEvent_shell::__shell())
    QWhatsThisClickedEvent_shell::__shell()->destructed(typeid(QWhatsThisClickedEvent));
}

void QWhatsThisClickedEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QWhatsThisClickedEvent_shell*>(ptr)->QWhatsThisClickedEvent_shell::__shell()->tryDeleteShell(typeid(QWhatsThisClickedEvent));
}

// emitting Virtual overrides (virtualFunctions)
QWhatsThisClickedEvent* QWhatsThisClickedEvent_shell::clone() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QWhatsThisClickedEvent::clone()const", QWhatsThisClickedEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QWhatsThisClickedEvent*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QWhatsThisClickedEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QWhatsThisClickedEvent* >(__jni_env, __java_return_value);
                    QtJambiAPI::setCppOwnership(__jni_env, __java_return_value);
                } else {
                    QWhatsThisClickedEvent_shell::__shell()->warnForMethod("QWhatsThisClickedEvent::clone()const");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QWhatsThisClickedEvent::clone()const");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QWhatsThisClickedEvent::clone();
        }
    }else{
        return QWhatsThisClickedEvent::clone();
    }
}

void QWhatsThisClickedEvent_shell::setAccepted(bool accepted0)
{
    if(jmethodID method_id = __shell_javaMethod(1)){
        QTJAMBI_JAVA_METHOD_CALL("QWhatsThisClickedEvent::", QWhatsThisClickedEvent_shell::__shell())
        if(JniEnvironment __jni_env{300}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QTJAMBI_TRY {
                if(jobject __java_this = QWhatsThisClickedEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    __jni_env->CallVoidMethod(__java_this, method_id, accepted0);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                } else {
                    QWhatsThisClickedEvent_shell::__shell()->warnForMethod("QWhatsThisClickedEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QWhatsThisClickedEvent::");
            } QTJAMBI_TRY_END
        }else{
            QEvent::setAccepted(static_cast<bool>(accepted0));
        }
    }else{
        QEvent::setAccepted(static_cast<bool>(accepted0));
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
void QWhatsThisClickedEvent_access::__qt_assign_cref_QWhatsThisClickedEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0)
{
    Q_UNUSED(__jni_env)
    Q_UNUSED(__this_nativeId)
    const QWhatsThisClickedEvent& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QWhatsThisClickedEvent>(__jni_env, other0);
    QWhatsThisClickedEvent::operator=(__qt_other0);
}

// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QWhatsThisClickedEvent_access::__qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        QWhatsThisClickedEvent* __qt_return_value = QWhatsThisClickedEvent::clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    } else {
        QWhatsThisClickedEvent* __qt_return_value = clone();
        jobject __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
        QtJambiAPI::setJavaOwnership(__jni_env, __java_return_value);
        return __java_return_value;
    }
}

// emitting (writeConstructors)
// new QWhatsThisClickedEvent(QString)
void __qt_construct_QWhatsThisClickedEvent_cref_QString(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWhatsThisClickedEvent(QString)")
    jstring href0 = static_cast<jstring>(__java_arguments[0].l);
    QString  __qt_href0 = qtjambi_cast<QString>(__jni_env, href0);
    QWhatsThisClickedEvent *__qt_this = new(__qtjambi_ptr) QWhatsThisClickedEvent_shell(__qt_href0);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QWhatsThisClickedEvent::QWhatsThisClickedEvent(QString)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QWhatsThisClickedEvent_initialize_1native__Lio_qt_gui_QWhatsThisClickedEvent_2Ljava_lang_String_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jstring href0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWhatsThisClickedEvent::QWhatsThisClickedEvent(QString)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = href0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWhatsThisClickedEvent_cref_QString, sizeof(QWhatsThisClickedEvent_shell), typeid(QWhatsThisClickedEvent), true, &deleter_QWhatsThisClickedEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QWhatsThisClickedEvent(QWhatsThisClickedEvent)
void __qt_construct_QWhatsThisClickedEvent_cref_QWhatsThisClickedEvent(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QWhatsThisClickedEvent(QWhatsThisClickedEvent)")
    jobject arg__1 = __java_arguments[0].l;
    const QWhatsThisClickedEvent& __qt_arg__1 = qtjambi_cast<const QWhatsThisClickedEvent& >(__jni_env, arg__1);
    QWhatsThisClickedEvent *__qt_this = new(__qtjambi_ptr) QWhatsThisClickedEvent_shell(__qt_arg__1);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QWhatsThisClickedEvent::QWhatsThisClickedEvent(QWhatsThisClickedEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QWhatsThisClickedEvent_initialize_1native__Lio_qt_gui_QWhatsThisClickedEvent_2Lio_qt_gui_QWhatsThisClickedEvent_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject arg__1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QWhatsThisClickedEvent::QWhatsThisClickedEvent(QWhatsThisClickedEvent)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = arg__1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QWhatsThisClickedEvent_cref_QWhatsThisClickedEvent, sizeof(QWhatsThisClickedEvent_shell), typeid(QWhatsThisClickedEvent), true, &deleter_QWhatsThisClickedEvent, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QWhatsThisClickedEvent_shell
void __qt_destruct_QWhatsThisClickedEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QWhatsThisClickedEvent")
    reinterpret_cast<QWhatsThisClickedEvent_shell*>(ptr)->~QWhatsThisClickedEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QWhatsThisClickedEvent::href()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QWhatsThisClickedEvent_href_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QWhatsThisClickedEvent *__qt_this = QtJambiAPI::objectFromNativeId<QWhatsThisClickedEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWhatsThisClickedEvent::href()const", __qt_this)
        QString __qt_return_value = __qt_this->href();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QWhatsThisClickedEvent::operator=(QWhatsThisClickedEvent)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QWhatsThisClickedEvent_assign_1native_1cref_1QWhatsThisClickedEvent__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QWhatsThisClickedEvent *__qt_this = QtJambiAPI::objectFromNativeId<QWhatsThisClickedEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWhatsThisClickedEvent::operator=(QWhatsThisClickedEvent)", __qt_this)
        static_cast<QWhatsThisClickedEvent_access*>(__qt_this)->__qt_assign_cref_QWhatsThisClickedEvent(__jni_env, __this_nativeId, other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QWhatsThisClickedEvent::clone()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QWhatsThisClickedEvent_clone_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QWhatsThisClickedEvent *__qt_this = QtJambiAPI::objectFromNativeId<QWhatsThisClickedEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QWhatsThisClickedEvent::clone()const", __qt_this)
        __java_return_value = static_cast<const QWhatsThisClickedEvent_access*>(__qt_this)->__qt_clone_constfct(__jni_env, __this_nativeId);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QWhatsThisClickedEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QWhatsThisClickedEvent>("QWhatsThisClickedEvent", "io/qt/gui/QWhatsThisClickedEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "clone", "()Lio/qt/gui/QWhatsThisClickedEvent;"),
        FunctionInfo(/* 1 */ "setAccepted", "(Z)V")});
    registerConstructorInfos(typeId, &__qt_destruct_QWhatsThisClickedEvent, {
        ConstructorInfo(&__qt_construct_QWhatsThisClickedEvent_cref_QString, "Ljava/lang/String;")
       ,ConstructorInfo(&__qt_construct_QWhatsThisClickedEvent_cref_QWhatsThisClickedEvent, "Lio/qt/gui/QWhatsThisClickedEvent;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QWhatsThisClickedEvent);
    registerSizeOfShell(typeId, sizeof(QWhatsThisClickedEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QEvent, QWhatsThisClickedEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
